"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildConfiguration = void 0;

var _extends2 = _interopRequireDefault(require("@babel/runtime/helpers/extends"));

var _types = require("@interaktiv/types");

var _utils = require("../lib/utils");

var _constants = require("../constants");

const buildConfiguration = async ({
  argv
}) => {
  const rootDir = resolveRootDir(argv);
  const paths = await (0, _utils.getAndValidateProjectPaths)(rootDir);
  const config = {};
  if (_constants.IOS_REGEXP.test(argv.platform) || _constants.IOS_REGEXP.test(argv.p)) config.platform = 'ios';else config.platform = argv.platform || argv.p;
  const OS_IOS = config.platform === 'ios'; // Distinguish between iOS (simulator, device, dist-appstore, dist-adhoc)
  // and Android (emulator, device, dist-playstore)

  let target = argv.target || argv.T;
  if (!target) target = OS_IOS ? 'simulator' : 'emulator';
  config.target = target; // Values: development, test, production

  let deployType = argv['deploy-type'];
  deployType = !/^dist-/.test(target) && deployType ? deployType : _constants.TARGET_DEPLOY_TYPES[target];
  config.deployType = deployType;
  config.ENV_PRODUCTION = deployType === _constants.DEPLOY_TYPES.ENV_PRODUCTION;
  config.DIST_ADHOC = _constants.DIST_TYPES.DIST_ADHOC.includes(target);
  const {
    miappenv
  } = argv;
  config.miappenv = miappenv;
  const {
    prefix = `${_constants.LTAG}: `
  } = argv;
  config.prefix = prefix;
  return (0, _extends2.default)({}, paths, config);
};
/**
 * Fetch correct project directory path, fallback to current NodeJS working dir
 *
 * @param {Object} argv The args passed to the appc cli
 * @returns {String} The root dir of the project
 */


exports.buildConfiguration = buildConfiguration;

function resolveRootDir(argv = {}) {
  const projectDir = argv['project-dir'];
  return (0, _types.isString)(projectDir) && projectDir.length > 0 ? projectDir : process.cwd();
}