"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.uninstall = exports.install = void 0;

var _path = _interopRequireDefault(require("path"));

var _execa = _interopRequireDefault(require("execa"));

var _json = require("@interaktiv/json");

var _types = require("@interaktiv/types");

var _debug = _interopRequireDefault(require("../debug"));

/* eslint-disable no-console */
const pkg = require('../../package.json');

function runCli(cmd, args = [], opts = {}) {
  return _execa.default.sync(cmd, [cmd === 'appc' ? 'ti' : null, ...args].filter(Boolean), opts);
}

function addHooks(cmd, filenames = []) {
  (0, _types.ensureString)(cmd);
  if ((0, _types.isArray)(filenames) === false || !filenames.length) return;
  const hooks = getHooks(cmd);
  const hooksToAppend = filenames.filter(file => {
    const alreadyAdded = hooks.includes(file);
    if (alreadyAdded) console.log(`skipping already added hook: ${file}`);
    return alreadyAdded === false;
  });
  if (!hooksToAppend.length) return;
  hooksToAppend.forEach(filename => {
    const {
      command,
      stderr,
      stdout
    } = runCli(cmd, ['config', '--append', 'paths.hooks', filename]);
    (0, _debug.default)(command);
    (0, _debug.default)(stdout);
    (0, _debug.default)(stderr);
  });
}

function removeHooks(cmd, filenames = []) {
  (0, _types.ensureString)(cmd);
  if ((0, _types.isArray)(filenames) === false || filenames.length <= 0) return;
  filenames.forEach(filename => {
    const {
      command,
      stderr,
      stdout
    } = runCli(cmd, ['config', '--remove', 'paths.hooks', filename]);
    (0, _debug.default)(command);
    (0, _debug.default)(stdout);
    (0, _debug.default)(stderr);
  });
}

function getHooks(cmd) {
  (0, _types.ensureString)(cmd);
  const {
    command,
    stderr,
    stdout
  } = runCli(cmd, ['config', 'paths.hooks', '--output', 'json']);
  (0, _debug.default)(command);
  (0, _debug.default)(stdout);
  (0, _debug.default)(stderr);
  const hooks = (0, _types.ensureJsonArray)((0, _json.parseJson)(stdout.trim(), '~/.titanium/config.json'));
  (0, _debug.default)(`Currently installed hooks: ${hooks}`);
  return hooks;
}

function getPluginHooks() {
  return [_path.default.resolve(__dirname, '..', 'hooks')];
}

const install = (titaniumCliCmd, isCI) => {
  // TODO: Add README.md hint about installation process
  // Checks
  if (isCI) {
    console.log('CI detected, skipping Titanium CLI hooks installation.');
    return;
  }

  if (titaniumCliCmd == null) {
    console.log('Trying to install without Titanium CLI, skipping hooks installation.');
    return;
  } // Remove previously added hooks from this plugin


  const hooks = getHooks(titaniumCliCmd);
  const [pkgName] = pkg.name.split('/');
  const PLUGIN_HOOK_REGEXP = new RegExp(pkgName, 'gm');
  removeHooks(titaniumCliCmd, hooks.filter(filename => PLUGIN_HOOK_REGEXP.test(filename))); // Re-add this version

  const pluginHooks = getPluginHooks();
  addHooks(titaniumCliCmd, pluginHooks);
};

exports.install = install;

const uninstall = titaniumCliCmd => {
  if (titaniumCliCmd == null) {
    console.log('Trying to uninstall without Titanium CLI, skipping hooks uninstallation.');
    return;
  }

  const pluginHooks = getPluginHooks();
  removeHooks(titaniumCliCmd, pluginHooks);
};
/* eslint-enable no-console */


exports.uninstall = uninstall;